package org.hibernate.event.service.internal;

import org.hibernate.cfg.Configuration;
import org.hibernate.engine.spi.SessionFactoryImplementor;
import org.hibernate.metamodel.source.MetadataImplementor;
import org.hibernate.service.Service;
import org.hibernate.service.internal.SessionFactoryServiceRegistryImpl;
import org.hibernate.service.spi.ServiceBinding;
import org.hibernate.service.spi.ServiceInitiator;
import org.hibernate.service.spi.ServiceRegistryImplementor;
import org.hibernate.service.spi.SessionFactoryServiceInitiator;

/**
 * customize to use StandardSessionFactoryServiceInitiators2
 * @author yding
 *
 */
public class SessionFactoryServiceRegistryImpl2 extends SessionFactoryServiceRegistryImpl  {

	// for now we need to hold on to the Configuration... :(
	private final Configuration configuration;
	private final MetadataImplementor metadata;
	private final SessionFactoryImplementor sessionFactory;

	@SuppressWarnings( {"unchecked"})
	public SessionFactoryServiceRegistryImpl2(
			ServiceRegistryImplementor parent,
			SessionFactoryImplementor sessionFactory,
			Configuration configuration) {
		super(parent, sessionFactory, configuration);

		this.sessionFactory = sessionFactory;
		this.configuration = configuration;
		this.metadata = null;

		// for now, just use the standard initiator list
		for ( SessionFactoryServiceInitiator initiator : StandardSessionFactoryServiceInitiators2.LIST ) {
			// create the bindings up front to help identify to which registry services belong
			createServiceBinding( initiator );
		}
	}

	@SuppressWarnings( {"unchecked"})
	public SessionFactoryServiceRegistryImpl2(
			ServiceRegistryImplementor parent,
			SessionFactoryImplementor sessionFactory,
			MetadataImplementor metadata) {
		super( parent,  sessionFactory, metadata);

		this.sessionFactory = sessionFactory;
		this.configuration = null;
		this.metadata = metadata;

		// for now, just use the standard initiator list
		for ( SessionFactoryServiceInitiator initiator : StandardSessionFactoryServiceInitiators2.LIST ) {
			// create the bindings up front to help identify to which registry services belong
			createServiceBinding( initiator );
		}
	}

	@Override
	public <R extends Service> R initiateService(ServiceInitiator<R> serviceInitiator) {
		// todo : add check/error for unexpected initiator types?
		SessionFactoryServiceInitiator<R> sessionFactoryServiceInitiator =
				(SessionFactoryServiceInitiator<R>) serviceInitiator;
		if ( metadata != null ) {
			return sessionFactoryServiceInitiator.initiateService( sessionFactory, metadata, this );
		}
		else if ( configuration != null ) {
			return sessionFactoryServiceInitiator.initiateService( sessionFactory, configuration, this );
		}
		else {
			throw new IllegalStateException( "Both metadata and configuration are null." );
		}
	}

	@Override
	public <R extends Service> void configureService(ServiceBinding<R> serviceBinding) {
		//TODO nothing to do here or should we inject SessionFactory properties?
	}

}
