package org.hibernate.internal;

import java.io.Serializable;
import java.sql.Connection;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.hibernate.CacheMode;
import org.hibernate.ConnectionReleaseMode;
import org.hibernate.Criteria;
import org.hibernate.Filter;
import org.hibernate.FlushMode;
import org.hibernate.HibernateException;
import org.hibernate.IdentifierLoadAccess;
import org.hibernate.Interceptor;
import org.hibernate.LobHelper;
import org.hibernate.LockMode;
import org.hibernate.LockOptions;
import org.hibernate.NaturalIdLoadAccess;
import org.hibernate.Query;
import org.hibernate.ReplicationMode;
import org.hibernate.SQLQuery;
import org.hibernate.ScrollMode;
import org.hibernate.ScrollableResults;
import org.hibernate.SessionFactory;
import org.hibernate.SharedSessionBuilder;
import org.hibernate.SharedSessionContract;
import org.hibernate.SimpleNaturalIdLoadAccess;
import org.hibernate.Transaction;
import org.hibernate.TypeHelper;
import org.hibernate.UnknownProfileException;
import org.hibernate.cache.spi.CacheKey;
import org.hibernate.collection.spi.PersistentCollection;
import org.hibernate.engine.jdbc.spi.JdbcConnectionAccess;
import org.hibernate.engine.query.spi.sql.NativeSQLQuerySpecification;
import org.hibernate.engine.spi.ActionQueue;
import org.hibernate.engine.spi.EntityEntry;
import org.hibernate.engine.spi.EntityKey;
import org.hibernate.engine.spi.LoadQueryInfluencers;
import org.hibernate.engine.spi.NonFlushedChanges;
import org.hibernate.engine.spi.PersistenceContext;
import org.hibernate.engine.spi.QueryParameters;
import org.hibernate.engine.spi.SessionFactoryImplementor;
import org.hibernate.engine.spi.SessionImplementor;
import org.hibernate.engine.transaction.spi.TransactionContext;
import org.hibernate.engine.transaction.spi.TransactionCoordinator;
import org.hibernate.engine.transaction.spi.TransactionEnvironment;
import org.hibernate.engine.transaction.spi.TransactionImplementor;
import org.hibernate.event.spi.EventSource;
import org.hibernate.jdbc.ReturningWork;
import org.hibernate.jdbc.Work;
import org.hibernate.loader.custom.CustomQuery;
import org.hibernate.persister.entity.EntityPersister;
import org.hibernate.stat.SessionStatistics;
import org.hibernate.type.Type;

public class SessionImplementorWithEntityKeyArray implements EventSource, Serializable, SharedSessionContract, SessionImplementor, TransactionContext{
	private EntityKey[] entityKeys;
	private SessionImpl session;
	
	public EntityKey[] getEntityKeys() {
		return entityKeys;
	}
	
	public SessionImplementorWithEntityKeyArray(SessionImpl session, EntityKey[] entityKeys) {
		this.session = session;
		this.entityKeys = entityKeys;
	}
	
	@Override
	public Interceptor getInterceptor() {
		return session.getInterceptor();
	}
	@Override
	public void setAutoClear(boolean enabled) {
		session.setAutoClear(enabled);
	}
	@Override
	public void disableTransactionAutoJoin() {
		session.disableTransactionAutoJoin();
	}
	@Override
	public boolean isTransactionInProgress() {
		return session.isTransactionInProgress();
	}
	@Override
	public void initializeCollection(PersistentCollection collection,
			boolean writing) throws HibernateException {
		session.initializeCollection(collection, writing);
	}
	@Override
	public Object internalLoad(String entityName, Serializable id,
			boolean eager, boolean nullable) throws HibernateException {
		return session.internalLoad(entityName, id, eager, nullable);
	}
	@Override
	public Object immediateLoad(String entityName, Serializable id)
			throws HibernateException {
		return session.immediateLoad(entityName, id);
	}
	@Override
	public long getTimestamp() {
		return session.getTimestamp();
	}
	@Override
	public List list(String query, QueryParameters queryParameters)
			throws HibernateException {
		return session.list(query, queryParameters);
	}
	@Override
	public Iterator iterate(String query, QueryParameters queryParameters)
			throws HibernateException {
		return session.iterate(query, queryParameters);
	}
	@Override
	public ScrollableResults scroll(String query,
			QueryParameters queryParameters) throws HibernateException {
		return session.scroll(query, queryParameters);
	}
	@Override
	public ScrollableResults scroll(CriteriaImpl criteria, ScrollMode scrollMode) {
		return session.scroll(criteria, scrollMode);
	}
	@Override
	public List list(CriteriaImpl criteria) {
		return session.list(criteria);
	}
	@Override
	public List listFilter(Object collection, String filter,
			QueryParameters queryParameters) throws HibernateException {
		return session.listFilter(collection, filter, queryParameters);
	}
	@Override
	public Iterator iterateFilter(Object collection, String filter,
			QueryParameters queryParameters) throws HibernateException {
		return session.iterateFilter(collection, filter, queryParameters);
	}
	@Override
	public EntityPersister getEntityPersister(String entityName, Object object)
			throws HibernateException {
		return session.getEntityPersister(entityName, object);
	}
	@Override
	public Object getEntityUsingInterceptor(EntityKey key)
			throws HibernateException {
		return session.getEntityUsingInterceptor(key);
	}
	@Override
	public Serializable getContextEntityIdentifier(Object object) {
		return session.getContextEntityIdentifier(object);
	}
	@Override
	public String bestGuessEntityName(Object object) {
		return session.bestGuessEntityName(object);
	}
	@Override
	public String guessEntityName(Object entity) throws HibernateException {
		return session.getEntityName(entity);
	}
	@Override
	public Object instantiate(String entityName, Serializable id)
			throws HibernateException {
		return session.instantiate(entityName, id);
	}
	@Override
	public List listCustomQuery(CustomQuery customQuery,
			QueryParameters queryParameters) throws HibernateException {
		return session.listCustomQuery(customQuery, queryParameters);
	}
	@Override
	public ScrollableResults scrollCustomQuery(CustomQuery customQuery,
			QueryParameters queryParameters) throws HibernateException {
		return session.scrollCustomQuery(customQuery, queryParameters);
	}
	@Override
	public Object getFilterParameterValue(String filterParameterName) {
		return session.getFilterParameterValue(filterParameterName);
	}
	@Override
	public Type getFilterParameterType(String filterParameterName) {
		return session.getFilterParameterType(filterParameterName);
	}
	@Override
	public Map getEnabledFilters() {
		return session.getEnabledFilters();
	}
	@Override
	public int getDontFlushFromFind() {
		return session.getDontFlushFromFind();
	}
	@Override
	public PersistenceContext getPersistenceContext() {
		return session.getPersistenceContext();
	}
	@Override
	public int executeUpdate(String query, QueryParameters queryParameters)
			throws HibernateException {
		return session.executeUpdate(query, queryParameters);
	}
	@Override
	public int executeNativeUpdate(NativeSQLQuerySpecification specification,
			QueryParameters queryParameters) throws HibernateException {
		return session.executeNativeUpdate(specification, queryParameters);
	}
	@Override
	public NonFlushedChanges getNonFlushedChanges() throws HibernateException {
		return session.getNonFlushedChanges();
	}
	@Override
	public void applyNonFlushedChanges(NonFlushedChanges nonFlushedChanges)
			throws HibernateException {
		session.applyNonFlushedChanges(nonFlushedChanges);
	}
	@Override
	public CacheMode getCacheMode() {
		return session.getCacheMode();
	}
	@Override
	public void setCacheMode(CacheMode cm) {
		session.setCacheMode(cm);
	}
	@Override
	public boolean isOpen() {
		return session.isOpen();
	}
	@Override
	public boolean isConnected() {
		return session.isConnected();
	}
	@Override
	public FlushMode getFlushMode() {
		return session.getFlushMode();
	}
	@Override
	public void setFlushMode(FlushMode fm) {
		session.setFlushMode(fm);
	}
	@Override
	public Connection connection() {
		return session.connection();
	}
	@Override
	public void flush() {
		session.flush();
	}
	@Override
	public boolean isEventSource() {
		return session.isEventSource();
	}
	@Override
	public void afterScrollOperation() {
		session.afterScrollOperation();
	}
	@Override
	public String getFetchProfile() {
		return session.getFetchProfile();
	}
	@Override
	public void setFetchProfile(String name) {
		session.setFetchProfile(name);
	}
	@Override
	public TransactionCoordinator getTransactionCoordinator() {
		return session.getTransactionCoordinator();
	}
	@Override
	public LoadQueryInfluencers getLoadQueryInfluencers() {
		return session.getLoadQueryInfluencers();
	}
	@Override
	public SharedSessionBuilder sessionWithOptions() {
		return session.sessionWithOptions();
	}
	@Override
	public SessionFactory getSessionFactory() {
		return session.getSessionFactory();
	}
	@Override
	public Connection close() throws HibernateException {
		return session.close();
	}
	@Override
	public void cancelQuery() throws HibernateException {
		session.cancelQuery();
	}
	@Override
	public boolean isDirty() throws HibernateException {
		return session.isDirty();
	}
	@Override
	public boolean isDefaultReadOnly() {
		return session.isDefaultReadOnly();
	}
	@Override
	public void setDefaultReadOnly(boolean readOnly) {
		session.setDefaultReadOnly(readOnly);
	}
	@Override
	public Serializable getIdentifier(Object object) {
		return session.getIdentifier(object);
	}
	@Override
	public boolean contains(Object object) {
		return session.contains(object);
	}
	@Override
	public void evict(Object object) {
		session.evict(object);
	}
	@Override
	public Object load(Class theClass, Serializable id, LockMode lockMode) {
		return session.load(theClass, id, lockMode);
	}
	@Override
	public Object load(Class theClass, Serializable id, LockOptions lockOptions) {
		return session.load(theClass, id, lockOptions);
	}
	@Override
	public Object load(String entityName, Serializable id, LockMode lockMode) {
		// TODO Auto-generated method stub
		return session.load(entityName, id, lockMode);
	}
	@Override
	public Object load(String entityName, Serializable id,
			LockOptions lockOptions) {
		return session.load(entityName, id, lockOptions);
	}
	@Override
	public Object load(Class theClass, Serializable id) {
		return session.load(theClass, id);
	}
	@Override
	public Object load(String entityName, Serializable id) {
		return session.load(entityName, id);
	}
	@Override
	public void load(Object object, Serializable id) {
		session.load(object, id);
	}
	@Override
	public void replicate(Object object, ReplicationMode replicationMode) {
		session.replicate(object, replicationMode);
	}
	@Override
	public void replicate(String entityName, Object object,
			ReplicationMode replicationMode) {
		session.replicate(entityName, object, replicationMode);
	}
	@Override
	public Serializable save(Object object) {
		return session.save(object);
	}
	@Override
	public Serializable save(String entityName, Object object) {
		return session.save(entityName, object);
	}
	@Override
	public void saveOrUpdate(Object object) {
		session.saveOrUpdate(object);
	}
	@Override
	public void saveOrUpdate(String entityName, Object object) {
		session.saveOrUpdate(entityName, object);
	}
	@Override
	public void update(Object object) {
		session.update(object);
	}
	@Override
	public void update(String entityName, Object object) {
		session.update(entityName, object);
	}
	@Override
	public Object merge(Object object) {
		return session.merge(object);
	}
	@Override
	public Object merge(String entityName, Object object) {
		return session.merge(entityName, object);
	}
	@Override
	public void persist(Object object) {
		session.persist(object);
	}
	@Override
	public void persist(String entityName, Object object) {
		session.persist(entityName, object);
	}
	@Override
	public void delete(Object object) {
		session.delete(object);
	}
	@Override
	public void delete(String entityName, Object object) {
		session.delete(entityName, object);
	}
	@Override
	public void lock(Object object, LockMode lockMode) {
		session.lock(object, lockMode);
	}
	@Override
	public void lock(String entityName, Object object, LockMode lockMode) {
		session.lock(entityName, object, lockMode);
	}
	@Override
	public LockRequest buildLockRequest(LockOptions lockOptions) {
		return session.buildLockRequest(lockOptions);
	}
	@Override
	public void refresh(Object object) {
		session.refresh(object);
	}
	@Override
	public void refresh(String entityName, Object object) {
		session.refresh(entityName, object);
	}
	@Override
	public void refresh(Object object, LockMode lockMode) {
		session.refresh(object, lockMode);
	}
	@Override
	public void refresh(Object object, LockOptions lockOptions) {
		session.refresh(object, lockOptions);
	}
	@Override
	public void refresh(String entityName, Object object,
			LockOptions lockOptions) {
		session.refresh(entityName, object, lockOptions);
	}
	@Override
	public LockMode getCurrentLockMode(Object object) {
		// TODO Auto-generated method stub
		return session.getCurrentLockMode(object);
	}
	@Override
	public Query createFilter(Object collection, String queryString) {
		return session.createFilter(collection, queryString);
	}
	@Override
	public void clear() {
		session.clear();
	}
	@Override
	public Object get(Class clazz, Serializable id) {
		return session.get(clazz, id);
	}
	@Override
	public Object get(Class clazz, Serializable id, LockMode lockMode) {
		return session.get(clazz, id, lockMode);
	}
	@Override
	public Object get(Class clazz, Serializable id, LockOptions lockOptions) {
		return session.get(clazz, id, lockOptions);
	}
	@Override
	public Object get(String entityName, Serializable id) {
		return session.get(entityName, id);
	}
	@Override
	public Object get(String entityName, Serializable id, LockMode lockMode) {
		return session.get(entityName, id, lockMode);
	}
	@Override
	public Object get(String entityName, Serializable id,
			LockOptions lockOptions) {
		return session.get(entityName, id, lockOptions);
	}
	@Override
	public String getEntityName(Object object) {
		return session.getEntityName(object);
	}
	@Override
	public IdentifierLoadAccess byId(String entityName) {
		return session.byId(entityName);
	}
	@Override
	public IdentifierLoadAccess byId(Class entityClass) {
		return session.byId(entityClass);
	}
	@Override
	public NaturalIdLoadAccess byNaturalId(String entityName) {
		return session.byNaturalId(entityName);
	}
	@Override
	public NaturalIdLoadAccess byNaturalId(Class entityClass) {
		return session.byNaturalId(entityClass);
	}
	@Override
	public SimpleNaturalIdLoadAccess bySimpleNaturalId(String entityName) {
		return session.bySimpleNaturalId(entityName);
	}
	@Override
	public SimpleNaturalIdLoadAccess bySimpleNaturalId(Class entityClass) {
		return session.bySimpleNaturalId(entityClass);
	}
	@Override
	public Filter enableFilter(String filterName) {
		return session.enableFilter(filterName);
	}
	@Override
	public Filter getEnabledFilter(String filterName) {
		return session.getEnabledFilter(filterName);
	}
	@Override
	public void disableFilter(String filterName) {
		session.disableFilter(filterName);
	}
	@Override
	public SessionStatistics getStatistics() {
		return session.getStatistics();
	}
	@Override
	public boolean isReadOnly(Object entityOrProxy) {
		return session.isReadOnly(entityOrProxy);
	}
	@Override
	public void setReadOnly(Object entityOrProxy, boolean readOnly) {
		session.setReadOnly(entityOrProxy, readOnly);
	}
	@Override
	public void doWork(Work work) throws HibernateException {
		session.doWork(work);
	}
	@Override
	public <T> T doReturningWork(ReturningWork<T> work)
			throws HibernateException {
		return session.doReturningWork(work);
	}
	@Override
	public Connection disconnect() {
		return session.disconnect();
	}
	@Override
	public void reconnect(Connection connection) {
		session.reconnect(connection);
	}
	@Override
	public boolean isFetchProfileEnabled(String name)
			throws UnknownProfileException {
		return session.isFetchProfileEnabled(name);
	}
	@Override
	public void enableFetchProfile(String name) throws UnknownProfileException {
		session.enableFetchProfile(name);
	}
	@Override
	public void disableFetchProfile(String name) throws UnknownProfileException {
		session.disableFetchProfile(name);
	}
	@Override
	public TypeHelper getTypeHelper() {
		return session.getTypeHelper();
	}
	@Override
	public LobHelper getLobHelper() {
		return session.getLobHelper();
	}
	@Override
	public Transaction beginTransaction() {
		return session.beginTransaction();
	}
	@Override
	public Transaction getTransaction() {
		return session.getTransaction();
	}
	@Override
	public Criteria createCriteria(Class persistentClass) {
		return session.createCriteria(persistentClass);
	}
	@Override
	public Criteria createCriteria(Class persistentClass, String alias) {
		return session.createCriteria(persistentClass, alias);
	}
	@Override
	public Criteria createCriteria(String entityName) {
		return session.createCriteria(entityName);
	}
	@Override
	public Criteria createCriteria(String entityName, String alias) {
		return session.createCriteria(entityName, alias);
	}
	@Override
	public ConnectionReleaseMode getConnectionReleaseMode() {
		return session.getConnectionReleaseMode();
	}
	@Override
	public boolean shouldAutoJoinTransaction() {
		return session.shouldAutoJoinTransaction();
	}
	@Override
	public boolean isAutoCloseSessionEnabled() {
		return session.isAutoCloseSessionEnabled();
	}
	@Override
	public boolean isFlushModeNever() {
		return session.isFlushModeNever();
	}
	@Override
	public boolean isFlushBeforeCompletionEnabled() {
		return session.isFlushBeforeCompletionEnabled();
	}
	@Override
	public void managedFlush() {
		session.managedFlush();
	}
	@Override
	public boolean shouldAutoClose() {
		return session.shouldAutoClose();
	}
	@Override
	public void managedClose() {
		session.managedClose();
	}
	@Override
	public void afterTransactionBegin(
			TransactionImplementor hibernateTransaction) {
		session.afterTransactionBegin(hibernateTransaction);
	}
	@Override
	public void beforeTransactionCompletion(
			TransactionImplementor hibernateTransaction) {
		session.beforeTransactionCompletion(hibernateTransaction);
	}
	@Override
	public void afterTransactionCompletion(
			TransactionImplementor hibernateTransaction, boolean successful) {
		session.afterTransactionCompletion(hibernateTransaction, successful);
	}
	@Override
	public String onPrepareStatement(String sql) {
		return session.onPrepareStatement(sql);
	}
	@Override
	public ActionQueue getActionQueue() {
		return session.getActionQueue();
	}
	@Override
	public Object instantiate(EntityPersister persister, Serializable id)
			throws HibernateException {
		return session.instantiate(persister, id);
	}
	@Override
	public void forceFlush(EntityEntry e) throws HibernateException {
		session.forceFlush(e);
	}
	@Override
	public void merge(String entityName, Object object, Map copiedAlready)
			throws HibernateException {
		session.merge(entityName, object, copiedAlready);
	}
	@Override
	public void persist(String entityName, Object object, Map createdAlready)
			throws HibernateException {
		session.persist(entityName, object, createdAlready);
	}
	@Override
	public void persistOnFlush(String entityName, Object object,
			Map copiedAlready) {
		session.persistOnFlush(entityName, object);
	}
	@Override
	public void refresh(Object object, Map refreshedAlready)
			throws HibernateException {
		session.refresh(object, refreshedAlready);
	}
	@Override
	public void delete(String entityName, Object child,
			boolean isCascadeDeleteEnabled, Set transientEntities) {
		session.delete(entityName, child, isCascadeDeleteEnabled, transientEntities);
	}
	@Override
	public <T> T execute(Callback<T> callback) {
		return session.execute(callback);
	}
	@Override
	public TransactionEnvironment getTransactionEnvironment() {
		return session.getTransactionEnvironment();
	}
	@Override
	public String getTenantIdentifier() {
		return session.getTenantIdentifier();
	}
	@Override
	public JdbcConnectionAccess getJdbcConnectionAccess() {
		return session.getJdbcConnectionAccess();
	}
	@Override
	public EntityKey generateEntityKey(Serializable id,
			EntityPersister persister) {
		return session.generateEntityKey(id, persister);
	}
	@Override
	public CacheKey generateCacheKey(Serializable id, Type type,
			String entityOrRoleName) {
		return session.generateCacheKey(id, type, entityOrRoleName);
	}
	@Override
	public SessionFactoryImplementor getFactory() {
		return session.getFactory();
	}
	@Override
	public List list(NativeSQLQuerySpecification spec,
			QueryParameters queryParameters) throws HibernateException {
		return session.list(spec, queryParameters);
	}
	@Override
	public ScrollableResults scroll(NativeSQLQuerySpecification spec,
			QueryParameters queryParameters) throws HibernateException {
		return session.scroll(spec, queryParameters);
	}
	@Override
	public Query getNamedQuery(String name) {
		return session.getNamedQuery(name);
	}
	@Override
	public Query getNamedSQLQuery(String name) {
		return session.getNamedQuery(name);
	}
	@Override
	public boolean isClosed() {
		return session.isClosed();
	}
	@Override
	public Query createQuery(String queryString) {
		return session.createQuery(queryString);
	}
	@Override
	public SQLQuery createSQLQuery(String queryString) {
		return session.createSQLQuery(queryString);
	}
}
